#
# spec file for package libqt5-qtwayland
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Internal QML imports of examples
%global __requires_exclude qmlimport\\(com.theqtcompany.*

%define qt5_snapshot 1
%define libname libQt5WaylandCompositor5
%define base_name libqt5
%define real_version 5.15.12
%define so_version 5.15.12
%define tar_version qtwayland-everywhere-src-%{version}
Name:           libqt5-qtwayland
Version:        5.15.12+kde60
Release:        1.2
Summary:        Qt 5 Wayland Addon
# The wayland compositor files are GPL-3.0-or-later
License:        GPL-3.0-or-later AND (LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-or-later)
Group:          Development/Libraries/X11
URL:            https://www.qt.io
Source:         %{tar_version}.tar.xz
Source1:        baselibs.conf
BuildRequires:  fdupes
BuildRequires:  libqt5-qtbase-private-headers-devel >= %{real_version}
BuildRequires:  libqt5-qtdeclarative-private-headers-devel >= %{real_version}
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(wayland-client) >= 1.1.0
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(wayland-server) >= 1.1.0
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xkbcommon) >= 0.2.0
Conflicts:      qtwayland
%if %{qt5_snapshot}
#to create the forwarding headers
BuildRequires:  perl
%endif

%description
Qt is a set of libraries for developing applications.

%package devel
Summary:        Qt 5 Wayland Addon
License:        GPL-3.0-or-later AND (LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-or-later)
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       libQt5WaylandClient5 = %{version}
Requires:       libQt5WaylandCompositor5 = %{version}
Conflicts:      qtwayland-devel

%description devel
Development package to build Qt-based compositors.

%package private-headers-devel
Summary:        Qt 5 Wayland Addon Non-ABI stable experimental API files
License:        GPL-3.0-or-later AND (LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-or-later)
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel = %{version}
Requires:       libqt5-qtbase-private-headers-devel
BuildArch:      noarch

%description private-headers-devel
This package provides private headers of libqt5-qtwayland that are normally
not used by application development and that do not have any ABI or
API guarantees. The packages that build against these have to require
the exact Qt version.

%package -n libQt5WaylandCompositor5
Summary:        Qt 5 Wayland Addon
License:        GPL-3.0-or-later AND (LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-or-later)
Group:          Development/Libraries/C and C++
Conflicts:      qtwayland

%description -n libQt5WaylandCompositor5
Qt is a set of libraries for developing applications.

%package -n libQt5WaylandClient5
Summary:        Qt 5 Wayland Addon
License:        GPL-3.0-or-later AND (LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-or-later)
Group:          Development/Libraries/C and C++
Conflicts:      qtwayland

%description -n libQt5WaylandClient5
Qt is a set of libraries for developing applications.

%package examples
Summary:        Qt5 wayland examples
License:        BSD-3-Clause
Group:          Development/Libraries/X11
Recommends:     %{name}-devel

%description examples
Examples for libqt5-qtwayland module.

%prep
%autosetup -p1 -n %{tar_version}

%post  -n libQt5WaylandCompositor5 -p /sbin/ldconfig
%postun -n libQt5WaylandCompositor5 -p /sbin/ldconfig
%post  -n libQt5WaylandClient5 -p /sbin/ldconfig
%postun -n libQt5WaylandClient5 -p /sbin/ldconfig
%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%build
%if %{qt5_snapshot}
#force the configure script to generate the forwarding headers (it checks whether .git directory exists)
mkdir .git
%endif
%{_libqt5_qmake} \
	CONFIG+=wayland-compositor

%make_jobs

%install
%qmake5_install

find %{buildroot}%{_libdir} -type f -name '*la' -print -exec perl -pi -e 's, -L%{_builddir}/\S+,,g' {} \;
find %{buildroot}%{_libdir}/pkgconfig -type f -name '*pc' -print -exec perl -pi -e 's, -L%{_builddir}/\S+,,g' {} \;
# kill .la files
rm -f %{buildroot}%{_libqt5_libdir}/lib*.la

fdupes -s %{buildroot}

%files
%license LICENSE.*
%{_libqt5_bindir}/qtwaylandscanner
%{_libqt5_plugindir}/
%{_libqt5_archdatadir}/qml/QtWayland/

%files -n libQt5WaylandCompositor5
%license LICENSE.*
%{_libqt5_libdir}/libQt5WaylandCompositor.so.*

%files -n libQt5WaylandClient5
%license LICENSE.*
%{_libqt5_libdir}/libQt5WaylandClient.so.*

%files devel
%license LICENSE.*
%{_libqt5_libdir}/*.prl
%{_libqt5_libdir}/*.so
%{_libqt5_libdir}/pkgconfig/*
%{_libqt5_libdir}/cmake/Qt5*/
%{_libqt5_archdatadir}/mkspecs/modules/*.pr?
%exclude %{_libqt5_includedir}/Qt*/%{so_version}
%{_libqt5_includedir}/Qt*

%files private-headers-devel
%license LICENSE.*
%{_libqt5_includedir}/Qt*/%{so_version}

%files examples
%license LICENSE.*
%{_libqt5_examplesdir}/

%changelog
* Fri Dec 29 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.12+kde60, rebased upstream:
  * Client: Always populate mimedata in drags
  * Client: Honor QGuiApplication::overrideCursor()
  * Always use blocking write for data_source.send
  * client: Mark return values as unused to suppress compiler warnings
  * tests: fix tst_seatv4 to use 24 as default cursor size
  * Bump version to 5.15.12
* Fri Oct  6 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.11+kde59, rebased upstream:
  * Client: Avoid locking resizing in QWaylandShmBackingStore
  * Client: Remove some surface commits
  * tests: Fix tst_xdgshell::minMaxSize()
  * Client: Commit the initial surface state explicitly
  * Remove unused variables
  * QtWaylandCompositor: includemocs
  * QtWaylandClient: includemocs
  * QtWaylandEglClientHwIntegrationPrivate: includemocs
  * QtWaylandTextureSharing: includemocs
  * QWaylandXdgShellIntegrationPlugin: includemocs
  * QtWlShellIntegrationPrivate: includemocs
  * Add missing QT_{BEGIN,END}_NAMESPACE
* Thu Sep 28 2023 Fabian Vogt <fvogt@suse.com>
- Update to version 5.15.10+kde58:
  * Client: Fix the mouse being stuck in pressed state after DnD
  * client: Fix infinite recursion with text-input-v2
  * Client: Fix buffer damage
  * Replace scale with devicePixelRatio for non-integer scaling
  * Convert cursor bitmap to supported format
  * client: Fix crash on dnd updates after client facing drag ends
  * Destroy frame queue before display
* Tue Jun 13 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.10+kde51, rebased upstream:
  * Fix compilation with GCC 12
- Commits dropped by the rebase:
  * Revert "Client: Ensure that wl_surface lives as long as qtquick render thread needs it"
  * Client: Ensure that wl_surface lives as long as qtquick render thread needs it
  * Build fixes for GCC 11
* Fri Apr 21 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.8+kde70, rebased upstream:
  * Don't keep eglConfig in hardwareintegration
  * Update the window geometry when changing decorations
  * Fix build with -no-feature-tabletevent
  * Fix wayland touch event to use time stamp from wayland compositor
  * wayland touch event to add key modifier
* Thu Mar 16 2023 Fabian Vogt <fvogt@suse.com>
- Update to version 5.15.8+kde63:
  * Client: Remove flip popup constraints
  * client: set_constraint_adjustment() for popups in xdg
  * client: Do not cast placeholder screens to QWaylandScreen
  * Client: Manage QMimeData lifecycle
  * client: Force a roundtrip when an XdgOutput is not ready yet
  * Client: Fix handling of Qt::BlankCursor
* Mon Jan  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.8+kde57, rebased upstream:
  * client: Avoid protocol error with invalid min/max size
  * Fixes the build on CentOS
  * Client: Handle zwp_primary_selection_device_manager_v1 global removal
  * Fix frame sync related to unprotected multithread access
  * Client: Bump wl_output version
  * Client: Call wl_output_release() upon QWaylandScreen destruction
  * Client: Add F_SEAL_SHRINK seal to shm backing file
  * Revert "Client: Ensure that wl_surface lives as long as qtquick render thread needs it"
  * Keep toplevel windows in the top left corner of the screen
  * Client: Ensure that wl_surface lives as long as qtquick render thread needs it
  * Use a correct serial for xdg_surface.ack_configure
  * tst_seatv4: fix compilation with GCC/C++20
  * tst_seatv4: fix deprecated implicit capture of this by [=]
* Thu Nov  3 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.7+kde49, rebased upstream:
  * Hold surface read lock throughout QWaylandEglWindow::updateSurface
  * Keep reference to buffer until it has been replaced
  * Implement wp_viewporter support for video buffer formats
  * Ignore viewporter buffer size when buffer is null
* Mon Sep 26 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.6+kde49, rebased upstream:
  * Call `finishDrag()` in `QWaylandDataDevice::dragSourceCancelled()`
  * Client: support high-dpi mode for window icon
  * Avoid calling requestUpdate from wrong thread
  * Fix missing update when toggling client-side decorations
  * Use CRLF line delimiter for text/uri-list data
  * Fix compile tests
  * client: Synthesize enter/leave event for popup in xdg-shell
  * Guard mResizeDirty by the correctMutex
  * Client: clear focus on touch cancel
  * Build fixes for GCC 11
  * Only close popup in the the hierchary
  * Cleanup up all subsurface QQuickItems correctly
  * linux-dmabuf-unstable-v1: Fix importing dmabuf buffers with modifiers
  * Add BlankCursor for cursor names map
  * client: Gracefully handle shutdown and window hiding
- Drop patches, now upstream:
  * 0002-Guard-mResizeDirty-by-the-correctMutex.patch
* Mon Jun 27 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.5+kde39, rebased upstream:
  * Fix build with libcxx (missing array include)
  * Reduce memory leakage
  * use poll(2) when reading from clipboard
  * Fix race condition on mWaitingForUpdateDelivery
  * Revert "Client: Remove mWaitingForUpdateDelivery"
  * client: update button state and etc in pointer_leave()
  * Docs: Add "instantiates" keywords
  * Add missing define guards
  * Fix touch being ignored when down and up are in the same frame
  * Fix race condition when attaching client to text input
  * Revert "Update commercial license headers"
  * Update commercial license headers
- Commits dropped by the rebase:
  * Fix backport, context destruction was omitted
  * Fix compilation
- Drop 0001-Revert-Bump-version.patch, it's versioned correctly now
- Drop patches, no longer directly applicable:
  * 0003-Fix-up-mutexes-for-frame-callbacks.patch
* Tue Feb 22 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.2+kde54:
  * Use proper dependencies in compile tests
  * Client: Fix opaque region setter
  * client: Simplify round trip behavior (boo#1196302)
  * Update the preedit styling mapping
  * Cursor position == 0 should still show the cursor
  * Client: Remove mWaitingForUpdateDelivery
  * Fix crash if no input method module could be loaded
  * Use wl_surface.damage_buffer on the client side
  * Do not create decorations when the shellSurface is not ready
  * Check pointer for null before use in ASSERT
- Drop patches, now upstream:
  * 0001-Client-Remove-mWaitingForUpdateDelivery.patch
  * 0001-Use-proper-dependencies-in-compile-tests.patch
* Thu Feb  3 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Add patches to fix applications not updating after some time (kde#449163):
  * 0001-Client-Remove-mWaitingForUpdateDelivery.patch
  * 0002-Guard-mResizeDirty-by-the-correctMutex.patch
  * 0003-Fix-up-mutexes-for-frame-callbacks.patch
- Add patch to fix several feature detection tests:
  * 0001-Use-proper-dependencies-in-compile-tests.patch
* Thu Jan 20 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.2+kde44:
  * Move the wayland socket polling to a separate event thread
  * Connect flushRequest after forceRoundTrip
  * Handle registry_global out of constructor
  * Client: Avoid processing of events when showing windows
  * Client: Delay deletion of QDrag object until after we're done with it
  * Client: Implement DataDeviceV3
  * Set preedit cursor when cursor equals to 0
- Drop patches, now upstream:
  * 0001-Client-Avoid-processing-of-events-when-showing-windo.patch
* Sun Dec 19 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.2+kde37:
  * Fix backport, context destruction was omitted
  * Client: do not empty clipboard when a new popup/window is opened
  * Wayland client: use wl_keyboard to determine active state
- Add patch to fix crashes triggered by unintentional actions when
  showing a window (kde#421700):
  * 0001-Client-Avoid-processing-of-events-when-showing-windo.patch
* Thu Oct 28 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.2+kde34:
  * Fix the logic for decoding modifiers map in Wayland text input protocol
  * Client: Always destroy frame callback in the actual callback
  * Client: Don't always recreate frame callbacks
  * Wayland client: Fix crash when windows are shown/hidden during drag
  * Correctly detect if image format is supported by QImageWriter
  * Do not update the mask if we do not have a surface
* Mon Jun 21 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Switch to KDE's maintenance branch
- Update to version 5.15.2+kde28:
  * Hook up queryKeyboardModifers
  * Fix: remove listener
  * Fix build
  * Client: Set XdgShell size hints before the first commit
  * Client: Disconnect registry listener on destruction
  * Client: Connect drags being accepted to updating the source drag icon
  * Include locale.h for setlocale/LC_CTYPE
  * Fix issue with repeated window size changes
  * Client: Announce an output after receiving more complete state
  * client: Allow QWaylandInputContext to accept composed key combinations
  * Fix compilation
  * xdgshell: Tell the compositor the screen we're expecting to fill
  * Get correct decoration margins region
  * Client: Send exposeEvent to parent on subsurface position changes
  * Translate opaque area with frame margins
  * Client: Send set_window_geometry only once configured
  * Fix memory leak in QWaylandGLContext
  * Use qWarning and _exit() instead of qFatal for wayland error
  * Fix leaked subsurface wayland items
  * Ensure that grabbing is performed in correct context
  * Make setting QT_SCALE_FACTOR work on Wayland
  * Do not try to eglMakeCurrent for unintended case
  * Make setting QT_SCALE_FACTOR work on Wayland
  * Scanner: Avoid accessing dangling pointers in destroy_func()
  * Add changes file for Qt 5.15.2
  * Doc: List correct license information for the module
  * Replace remaining LGPLv3 headers in QtWaylandCompositor with GPLv3
  * Bump version
- Add patch to reset version to 5.15.2:
  * 0001-Revert-Bump-version.patch
- Drop patches, now upstream:
  * 0001-Scanner-Avoid-accessing-dangling-pointers-in-destroy.patch
  * 0002-Make-setting-QT_SCALE_FACTOR-work-on-Wayland.patch
  * 0003-Do-not-try-to-eglMakeCurrent-for-unintended-case.patch
  * 0004-Make-setting-QT_SCALE_FACTOR-work-on-Wayland.patch
  * 0005-Ensure-that-grabbing-is-performed-in-correct-context.patch
  * 0006-Fix-leaked-subsurface-wayland-items.patch
  * 0007-Use-qWarning-and-_exit-instead-of-qFatal-for-wayland.patch
  * 0008-Fix-memory-leak-in-QWaylandGLContext.patch
  * 0009-Client-Send-set_window_geometry-only-once-configured.patch
  * 0010-Translate-opaque-area-with-frame-margins.patch
  * 0011-Client-Send-exposeEvent-to-parent-on-subsurface-posi.patch
  * 0012-Get-correct-decoration-margins-region.patch
  * 0013-xdgshell-Tell-the-compositor-the-screen-we-re-expect.patch
  * 0014-Fix-compilation.patch
  * 0015-client-Allow-QWaylandInputContext-to-accept-composed.patch
  * 0016-Client-Announce-an-output-after-receiving-more-compl.patch
  * 0017-Fix-issue-with-repeated-window-size-changes.patch
  * 0018-Include-locale.h-for-setlocale-LC_CTYPE.patch
* Sun May 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add more commits from KDE's 5.15 branch:
  * 0008-Fix-memory-leak-in-QWaylandGLContext.patch (QTBUG-85608)
  * 0009-Client-Send-set_window_geometry-only-once-configured.patch
  * 0010-Translate-opaque-area-with-frame-margins.patch
  * 0011-Client-Send-exposeEvent-to-parent-on-subsurface-posi.patch
    (QTBUG-86177)
  * 0012-Get-correct-decoration-margins-region.patch
  * 0013-xdgshell-Tell-the-compositor-the-screen-we-re-expect.patch
  * 0014-Fix-compilation.patch
  * 0015-client-Allow-QWaylandInputContext-to-accept-composed.patch
    (kde#405388)
  * 0016-Client-Announce-an-output-after-receiving-more-compl.patch
    (kde#435124)
  * 0017-Fix-issue-with-repeated-window-size-changes.patch
  * 0018-Include-locale.h-for-setlocale-LC_CTYPE.patch
* Wed Apr  7 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add commits from upstream's 5.15 branch:
  * 0002-Make-setting-QT_SCALE_FACTOR-work-on-Wayland.patch (QTBUG-87762)
  * 0003-Do-not-try-to-eglMakeCurrent-for-unintended-case.patch (QTBUG-88277)
  * 0004-Make-setting-QT_SCALE_FACTOR-work-on-Wayland.patch (QTBUG-87762, QTBUG-88064)
  * 0005-Ensure-that-grabbing-is-performed-in-correct-context.patch (QTBUG-87597)
  * 0006-Fix-leaked-subsurface-wayland-items.patch (QTBUG-88782)
- Add commit from KDE's 5.15 branch:
  * 0007-Use-qWarning-and-_exit-instead-of-qFatal-for-wayland.patch
* Sat Jan 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add compatibility with qml-autoreqprov
* Tue Dec  1 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch to fix a regression:
  * 0001-Scanner-Avoid-accessing-dangling-pointers-in-destroy.patch
* Fri Nov 20 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.2:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtwayland.git/plain/dist/changes-5.15.2/?h=5.15.2
* Thu Sep 10 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.1:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtwayland.git/plain/dist/changes-5.15.1/?h=5.15.1
* Tue May 26 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 5.15.0:
  * No changelog available
* Wed May 20 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 5.15.0-rc2:
  * No changelog available
* Wed May  6 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-rc:
  * New bugfix release
  * For the changes between 5.14.2 and 5.15.0 please see:
    http://code.qt.io/cgit/qt/qtwayland.git/plain/dist/changes-5.15.0/?h=5.15.0
* Fri Apr 24 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta4:
  * New bugfix release
  * No changelog available
* Tue Apr 14 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta3:
  * New bugfix release
  * No changelog available
* Tue Mar 24 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Feb 28 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta1:
  * New bugfix release
  * No changelog available
* Wed Feb 19 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-alpha:
  * New feature release
  * For more details please see:
    https://wiki.qt.io/New_Features_in_Qt_5.15
- Drop patches, now upstream:
  * fix-return-nonvoid-function.patch
* Mon Jan 27 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.1:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtwayland.git/plain/dist/changes-5.14.1/?h=v5.14.1
- Drop patches, now upstream:
  * 0001-Avoid-animating-single-frame-cursors.patch
* Sun Dec 22 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Remove unneeded parentheses in License tag
* Mon Dec 16 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update the license tags.
* Thu Dec 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0:
  * New bugfix release
  * For the changes between 5.13.2 and 5.14.0 please see:
    https://code.qt.io/cgit/qt/qtwayland.git/tree/dist/changes-5.14.0?h=v5.14.0
  * For the changes between 5.13.1 and 5.13.2 please see:
    https://code.qt.io/cgit/qt/qtwayland.git/tree/dist/changes-5.13.2?h=v5.14.0
* Wed Dec  4 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-rc:
  * New bugfix release
  * No changelog available
  * For more details please see:
  * For more details about Qt 5.14 please see:
    https://wiki.qt.io/New_Features_in_Qt_5.14
- Add patch to address performance regression (kde#412924):
  * 0001-Avoid-animating-single-frame-cursors.patch
* Tue Nov 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta3:
  * New bugfix release
  * No changelog available
* Thu Oct 24 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta2:
  * New bugfix release
  * No changelog available
* Tue Oct 15 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta1:
  * New bugfix release
  * No changelog available
* Mon Sep 30 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-alpha:
  * New feature release
  * No changelog available
  * For more details about Qt 5.14 please see:
    https://wiki.qt.io/New_Features_in_Qt_5.14
- Drop patch, cause of the regression was reverted in qtbase:
  * 0003-Client-Don-t-send-fake-SurfaceCreated-Destroyed-even.patch
- Drop patch, now upstream:
  * 0004-Client-Make-handleUpdate-aware-of-exposure-changes.patch
- Drop patch, it's (hopefully) no longer necessary:
  * workaround-null-object.patch
- Add patch to fix build:
  * fix-return-nonvoid-function.patch
* Fri Sep  6 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.13.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtwayland.git/plain/dist/changes-5.13.1/?h=v5.13.1
- Drop patches, now upstream:
  * 0001-Don-t-crash-if-we-start-a-drag-without-dragFocus.patch
  * 0002-Client-Fix-stuttering-when-the-GUI-thread-is-busy.patch
  * 0005-Client-Reset-frame-callback-timer-when-hiding-a-wind.patch
  * 0001-Fix-use-of-private-dependency.patch
* Thu Aug 15 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix deps in Qt5WaylandClient.pc and .cmake:
  * 0001-Fix-use-of-private-dependency.patch
* Wed Jul  3 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch from upstream 5.13 branch to fix crashes:
  * 0001-Don-t-crash-if-we-start-a-drag-without-dragFocus.patch
- Add patch from upstream 5.12 branch to improve performance:
  * 0002-Client-Fix-stuttering-when-the-GUI-thread-is-busy.patch
- Add patches from upstream code reviews to fix various issues:
  * 0003-Client-Don-t-send-fake-SurfaceCreated-Destroyed-even.patch
  * 0004-Client-Make-handleUpdate-aware-of-exposure-changes.patch
  * 0005-Client-Reset-frame-callback-timer-when-hiding-a-wind.patch
* Wed Jun 19 2019 fabian@ritter-vogt.de
- Update to 5.13.0:
  * New bugfix release
  * No changelog available
  * For more details about Qt 5.13 please see:
  * http://code.qt.io/cgit/qt/qtwayland.git/plain/dist/changes-5.13.0/?h=5.13
* Tue Jun  4 2019 fabian@ritter-vogt.de
- Update to 5.13.0-rc:
  * New bugfix release
  * No changelog available
- Drop patches, bug fixed upstream:
  * 0001-Revert-Fix-compilation-with-QT_NO_WARNING_OUTPUT.patch
  * 0002-Revert-Client-Don-t-send-illegal-wl_pointer.set_curs.patch
  * 0003-Revert-Client-tests-Add-convenience-for-getting-curs.patch
  * 0004-Revert-Client-Decrease-buffer_scale-for-small-cursor.patch
  * 0005-Revert-Client-Refactor-cursors-and-fix-various-bugs.patch
* Sat May 18 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Revert upstream commits to hopefully fix kscreenlocker crash (kde#407653):
  * 0001-Revert-Fix-compilation-with-QT_NO_WARNING_OUTPUT.patch
  * 0002-Revert-Client-Don-t-send-illegal-wl_pointer.set_curs.patch
  * 0003-Revert-Client-tests-Add-convenience-for-getting-curs.patch
  * 0004-Revert-Client-Decrease-buffer_scale-for-small-cursor.patch
  * 0005-Revert-Client-Refactor-cursors-and-fix-various-bugs.patch
* Mon Apr 29 2019 fabian@ritter-vogt.de
- Update to 5.13.0-beta2:
  * New bugfix release
  * No changelog available
* Thu Apr 18 2019 fabian@ritter-vogt.de
- Update to 5.12.3:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtwayland.git/plain/dist/changes-5.12.3/?h=v5.12.3
* Thu Mar 21 2019 fabian@ritter-vogt.de
- Update to 5.13.0-beta1:
  * New feature release
  * For more details about Qt 5.13 please see:
  * http://code.qt.io/cgit/qt/qtwayland.git/plain/dist/changes-5.13.0/?h=5.13
* Thu Mar 14 2019 fabian@ritter-vogt.de
- Update to 5.12.2:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtwayland.git/plain/dist/changes-5.12.2/?h=5.12.2
* Fri Feb  1 2019 fabian@ritter-vogt.de
- Update to 5.12.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtwayland.git/plain/dist/changes-5.12.1/?h=v5.12.1
* Thu Dec  6 2018 fabian@ritter-vogt.de
- Update to 5.12.0:
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtwayland.git/plain/dist/changes-5.12.0/?h=v5.12.0
* Mon Dec  3 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc2:
  * New bugfix release
  * Only important bugfixes
- Changelog for Qt 5.12.0:
  * http://code.qt.io/cgit/qt/qtwayland.git/plain/dist/changes-5.12.0/?h=5.12.0
* Thu Nov 22 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc:
  * New bugfix release
  * No changelog available
* Thu Nov  8 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta4:
  * New bugfix release
  * No changelog available
* Fri Oct 26 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta3:
  * New bugfix release
  * No changelog available
* Wed Oct 17 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta2:
  * New bugfix release
  * No changelog available
- Remove patches, now upstream:
  * 0001-Avoid-spurious-move-events-after-configure-call.patch
* Mon Oct  8 2018 fabian@ritter-vogt.de
- Add patch to fix window geometry in specific situations:
  * 0001-Avoid-spurious-move-events-after-configure-call.patch
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta1:
  * New bugfix release
  * No changelog available
- Remove patches, now upstream:
  * fix-deadlock.patch
* Tue Oct  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0-alpha:
  * New feature release
  * For more details please see:
  * http://wiki.qt.io/New_Features_in_Qt_5.12
- Add patch to fix deadlock when calling makeCurrent before exposing:
  * fix-deadlock.patch
* Fri Sep 21 2018 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtwayland.git/plain/dist/changes-5.11.2/?h=v5.11.2
* Sat Jul  7 2018 fabian@ritter-vogt.de
- Remove patch as it causes a regression with resizing windows:
  * 0001-Handle-maximize-minimize-fullscreen-xdgshellv6.patch
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtwayland.git/plain/dist/changes-5.11.1/?h=v5.11.1
* Tue May 22 2018 fabian@ritter-vogt.de
- Update to 5.11.0
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtwayland.git/plain/dist/changes-5.11.0/?h=v5.11.0
* Tue May  8 2018 fabian@ritter-vogt.de
- Update to 5.11.0-rc
  * New bugfix release
  * No changelog available
* Mon Apr 23 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta4
  * New bugfix release
  * No changelog available
* Wed Apr 11 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta3
  * New bugfix release
  * No changelog available
* Wed Mar 28 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta2
  * New bugfix release
  * No changelog available
- Refresh 0001-Handle-maximize-minimize-fullscreen-xdgshellv6.patch
* Tue Mar 13 2018 christophe@krop.fr
- Fix the license tag.
* Thu Mar  1 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta1
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtwayland.git/plain/dist/changes-5.11.0-beta1/?h=v5.11.0-beta1
* Tue Feb 20 2018 fabian@ritter-vogt.de
- Update to 5.11.0-alpha
  * New feature release
  * For more details please see:
  * https://wiki.qt.io/New_Features_in_Qt_5.11
- Remove patches, now upstream:
  * 0001-Implement-basic-key-composition-support.patch
  * 0002-Automatically-change-scale-when-entering-a-new-outpu.patch
* Wed Feb 14 2018 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtwayland.git/plain/dist/changes-5.10.1/?h=v5.10.1
- Drop patches, now upstream:
  * Dont-recreate-hidden-egl-surfaces.patch
* Sat Feb 10 2018 fabian@ritter-vogt.de
- Add patch (pending upstream) to implement fullscreen windows for
  xdg-shell v6 (boo#1080447):
  * 0001-Handle-maximize-minimize-fullscreen-xdgshellv6.patch
* Tue Jan  9 2018 fabian@ritter-vogt.de
- Add patch (pending upstream) to fix destruction of hidden surfaces (kde#381630):
  * Dont-recreate-hidden-egl-surfaces.patch
- Keep workaround-null-object.patch as it can in theory prevent
  crashes and has no effect otherwise
* Mon Jan  1 2018 fabian@ritter-vogt.de
- Add patch from upstream dev branch for compose key support:
  * 0001-Implement-basic-key-composition-support.patch
- Add fix from upstream dev branch:
  * 0002-Automatically-change-scale-when-entering-a-new-outpu.patch
* Fri Dec  8 2017 christophe@krop.fr
- Update the license tag (boo#967696)
* Thu Dec  7 2017 fabian@ritter-vogt.de
- Update to 5.10.0 final
  * New bugfix release
* Sun Dec  3 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 2
  * New bugfix release
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 1
  * New bugfix release
* Sat Nov 25 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details, see:
    http://code.qt.io/cgit/qt/qtwayland.git/tree/dist/changes-5.9.3/?h=v5.9.3
* Wed Nov 15 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 4
- Contains bugfixes
* Thu Nov  2 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 3
- Contains bugfixes
* Mon Oct 30 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 2
- Contains bugfixes
* Mon Oct  9 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 1
- For more information visit:
    https://blog.qt.io/blog/2017/10/09/qt-5-10-beta-released/
* Sun Oct  8 2017 lbeltrame@kde.org
- Update to 5.9.2
  * For more details please see:
    https://blog.qt.io/blog/2017/10/06/qt-5-9-2-released/
* Mon Sep 25 2017 fabian@ritter-vogt.de
- Update to 5.10 Alpha 1
- For more information visit:
    https://blog.qt.io/blog/2017/09/13/qt-5-10-alpha-released/
* Thu Sep 14 2017 fabian@ritter-vogt.de
- Add patch to workaround crash due to nullptr deref (kde#381630):
  * workaround-null-object.patch
* Sat Jul  1 2017 lbeltrame@kde.org
- Update to 5.9.1
  * For more details please see:
    http://blog.qt.io/blog/2017/06/30/qt-5-9-1-released/
* Wed May 31 2017 fabian@ritter-vogt.de
- Update to 5.9.0 final
* Wed May 24 2017 fabian@ritter-vogt.de
- Update to 5.9.0 RC:
  * For more details please see:
    http://lists.qt-project.org/pipermail/announce/2017-May/000115.html
    and https://wiki.qt.io/New_Features_in_Qt_5.9
* Wed Dec 14 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * For more details please see:
    https://blog.qt.io/blog/2016/12/14/qt-5-7-1-released/
    and https://www.qt.io/qt5-7/
* Sat Sep 24 2016 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * For more details please see:
    https://www.qt.io/qt5-7/
- Drop dead 0001-partially-revert-505c373.diff
* Wed Jun  8 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * For more details please see:
    http://blog.qt.io/blog/2016/06/08/qt-5-6-1-released/
* Fri Mar 18 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * For more details please see:
    http://blog.qt.io/blog/2016/03/16/qt-5-6-released/
    and https://wiki.qt.io/New_Features_in_Qt_5.6
- Drop adjust_api.diff, we don't need nor want to support Qt 5.3
- Added 0001-partially-revert-505c373.diff: use pkgconfig to gather
  wayland includes
* Fri Oct 16 2015 hrvoje.senjan@gmail.com
- Update to 5.5.1
  * For more details please see:
    http://blog.qt.io/blog/2015/10/15/qt-5-5-1-released/
* Sun Aug 16 2015 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * For more details please see:
    http://blog.qt.io/blog/2015/07/01/qt-5-5-released/
    and https://wiki.qt.io/New_Features_in_Qt_5.5
* Wed Jun  3 2015 hrvoje.senjan@gmail.com
- Update to 5.4.2
  * Bugfix release, for more details please see:
    http://blog.qt.io/blog/2015/06/02/qt-5-4-2-released/
- Drop Run-eventDispatcher-in-QWaylandDisplayforceRoundTrip.patch,
  merged upstream
* Sat May  9 2015 hrvoje.senjan@gmail.com
- Added Run-eventDispatcher-in-QWaylandDisplayforceRoundTrip.patch
* Tue Feb 24 2015 hrvoje.senjan@gmail.com
- Update to 5.4.1
  * For more details please see:
    http://blog.qt.io/blog/2015/02/24/qt-5-4-1-released/
* Wed Dec 10 2014 hrvoje.senjan@gmail.com
- Update to 5.4 Final
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/12/10/qt-5-4-released/
    and http://qt-project.org/wiki/New-Features-in-Qt-5.4
* Thu Nov 27 2014 hrvoje.senjan@gmail.com
- Update to 5.4 RC
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/11/27/qt-5-4-release-candidate-available/
    and http://qt-project.org/wiki/New-Features-in-Qt-5.4
* Fri Oct 17 2014 hrvoje.senjan@gmail.com
- Update to 5.4.0 beta
  * New feature release, please see
  http://blog.qt.digia.com/blog/2014/10/17/qt-5-4-beta-available/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.4
- Added adjust_api.diff, to guard QPA usage found in 5.3 and 5.4
* Mon Sep  8 2014 hrvoje.senjan@gmail.com
- Update to 5.4.0 alpha:
  * Part of the official Qt release
